@@ -283,6 +283,7 @@ graphene_quaternion_slerp (const graphene_quaternion_t *a,
   graphene_simd4f_t v_b = graphene_simd4f_init (b->x, b->y, b->z, b->w);
 
   float dot = CLAMP (graphene_simd4f_get_x (graphene_simd4f_dot4 (v_a, v_b)), -1.f, 1.f);
+
   if (graphene_approx_val (dot, 1.f))
     {
       *res = *a;
@@ -429,29 +430,25 @@ graphene_quaternion_to_radians (const graphene_quaternion_t *q,
                                 float                       *rad_z)
 {
   graphene_vec4_t v;
-  graphene_vec4_t sq;
+  graphene_vec4_t sqv;
 
   graphene_quaternion_to_vec4 (q, &v);
-  graphene_vec4_multiply (&v, &v, &sq);
+  graphene_vec4_multiply (&v, &v, &sqv);
 
-  float qx = graphene_vec4_get_x (&v);
-  float qy = graphene_vec4_get_y (&v);
-  float qz = graphene_vec4_get_z (&v);
-  float qw = graphene_vec4_get_w (&v);
+  float qa[4];
+  graphene_vec4_to_float (&v, qa);
 
-  float sqx = graphene_vec4_get_x (&sq);
-  float sqy = graphene_vec4_get_y (&sq);
-  float sqz = graphene_vec4_get_z (&sq);
-  float sqw = graphene_vec4_get_w (&sq);
+  float sqa[4];
+  graphene_vec4_to_float (&sqv, sqa);
 
   if (rad_x != NULL)
-    *rad_x = atan2f (2 * (qx * qw - qy * qz), (sqw - sqx - sqy + sqz));
+    *rad_x = atan2f (2 * (qa[0] * qa[3] - qa[1] * qa[2]), (sqa[3] - sqa[0] - sqa[1] + sqa[2]));
 
   if (rad_y != NULL)
-    *rad_y = asinf (CLAMP (2 * ( qx * qz + qy * qw), -1, 1));
+    *rad_y = asinf (CLAMP (2 * (qa[0] * qa[2] + qa[1] * qa[3]), -1, 1));
 
   if (rad_z != NULL)
-    *rad_z = atan2f (2 * (qz * qw - qx * qy), (sqw + sqx - sqy - sqz));
+    *rad_z = atan2f (2 * (qa[2] * qa[3] - qa[0] * qa[1]), (sqa[3] + sqa[0] - sqa[1] - sqa[2]));
 }
 
 /**
@@ -519,7 +516,7 @@ graphene_quaternion_to_angle_vec3 (const graphene_quaternion_t *q,
       float sin_a = sqrtf (1.f - cos_a * cos_a);
 
       if (fabsf (sin_a) < 0.00005)
-       sin_a = 1.f;
+        sin_a = 1.f;
 
       graphene_vec3_init (axis, q_n.x / sin_a, q_n.y / sin_a, q_n.z / sin_a);
     }
@@ -616,6 +613,19 @@ graphene_quaternion_init_from_euler (graphene_quaternion_t  *q,
   return q;
 }
 
+static bool
+quaternion_equal (const void *p1,
+                  const void *p2)
+{
+  const graphene_quaternion_t *a = p1;
+  const graphene_quaternion_t *b = p2;
+
+  return fabsf (a->x - b->x) < 0.00001 &&
+         fabsf (a->y - b->y) < 0.00001 &&
+         fabsf (a->z - b->z) < 0.00001 &&
+         fabsf (a->w - b->w) < 0.00001;
+}
+
 /**
  * graphene_quaternion_equal:
  * @a: a #graphene_quaternion_t
@@ -631,16 +641,7 @@ bool
 graphene_quaternion_equal (const graphene_quaternion_t *a,
                            const graphene_quaternion_t *b)
 {
-  if (a == b)
-    return true;
-
-  if (a == NULL || b == NULL)
-    return false;
-
-  return fabsf (a->x - b->x) < 0.00001 &&
-         fabsf (a->y - b->y) < 0.00001 &&
-         fabsf (a->z - b->z) < 0.00001 &&
-         fabsf (a->w - b->w) < 0.00001;
+  return graphene_pointer_equal (a, b, quaternion_equal);
 }
 
 /**
